<?php

namespace App;


use App\Models\Rating;
use Carbon\Carbon;
use Illuminate\Notifications\Notifiable;
use Illuminate\Foundation\Auth\User as Authenticatable;

class User extends Authenticatable
{
    use Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    public function scopeActive($query)
    {
        $query->where('status', 'active');
    }

    public function setImageAttribute($image)
    {
        $file = request()->file('image');
        $destinationPath = 'images/user/';
        $filename = $file->getClientOriginalName();
        $file->move($destinationPath, $filename);
        $this->attributes['image'] = $filename;
    }

    public function setPasswordAttribute($password)
    {
        if (isset($password)) {
            $this->attributes['password'] = bcrypt($password);
        }
    }

    public function getDateOfRegisterAttribute($value)
    {
        return Carbon::parse($value)->format('d/m/Y');
    }

    public function activate()
    {
        $var = route('active_user', ['id' => $this->id]);
        $token = csrf_token();
        if ($this->status == 'active') {
            return "<form style='margin-top: 20px' method='POST' action='$var' class='form-horizontal'>
                <input type='hidden' name='_token' value='$token'>
                <button type='submit' class='btn btn-danger btn-rounded waves-effect waves-light'>
                <span class='btn-label'><i class='fa fa-times'></i></span>
                الغاء التفعيل</button>
                
            </form>";
        }
        return "<form style='margin-top: 20px' method='POST' action='$var' class='form'>
                <input type='hidden' name='_token' value='$token'>
                <button type='submit' class='btn btn-success btn-rounded waves-effect waves-light'>
                <span class='btn-label'><i class='fa fa-check'></i></span>
                تفعيل</button>
                
            </form>";
    }


    protected $fillable = [
        'name', 'email', 'phone', 'id_number', 'pay', 'lat', 'lng', 'password', 'status', 'confirm', 'type', 'image'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    public function Ratings()
    {
        return $this->hasMany(Rating::class, 'user_id', 'id');
    }
//    public function Ads()
//    {
//        return $this->hasMany(Ad::class, 'user_id', 'id');
//    }
//    public function Messages()
//    {
//        return $this->hasMany(Message::class, 'user_id', 'id');
//    }


//    public function favItems()
//    {
//        return $this->belongsToMany(Item::class, 'favorites', 'user_id', 'item_id');
//    }


    public function getDistanceBetweenPoints($sat7a_lat, $sat7a_lng, $lang)
    {
        $user_lat = $this->attributes['lat'];
        $user_lng = $this->attributes['lng'];
        $theta = $user_lng - $sat7a_lng;
        $distance = (sin(deg2rad($user_lat)) * sin(deg2rad($sat7a_lat))) + (cos(deg2rad($user_lat)) * cos(deg2rad($sat7a_lat)) * cos(deg2rad($theta)));
        $distance = acos($distance);
        $distance = rad2deg($distance);
        $distance = $distance * 60 * 1.1515;


        if ($distance >= 1) {
            if ($lang == 'ar') {
                return (round($distance) . ' كم ');
            } else {
                return (round($distance) . ' km ');
            }
        } else {

            $meter = $distance * 1000;
            if ($lang == 'ar') {

                return (round($meter). ' م');
            } else {
                return (round($meter). ' m');

            }
        }


    }
}
